@@ -1,5 +1,7 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
+
 """
 Astroid hook for the attrs library
 
@@ -9,9 +11,18 @@ for attrs classes
 from astroid.manager import AstroidManager
 from astroid.nodes.node_classes import AnnAssign, Assign, AssignName, Call, Unknown
 from astroid.nodes.scoped_nodes import ClassDef
+from astroid.util import safe_infer
 
 ATTRIB_NAMES = frozenset(
-    ("attr.ib", "attrib", "attr.attrib", "attr.field", "attrs.field", "field")
+    (
+        "attr.Factory",
+        "attr.ib",
+        "attrib",
+        "attr.attrib",
+        "attr.field",
+        "attrs.field",
+        "field",
+    )
 )
 ATTRS_NAMES = frozenset(
     (
@@ -29,9 +40,8 @@ ATTRS_NAMES = frozenset(
 )
 
 
-def is_decorated_with_attrs(node, decorator_names=ATTRS_NAMES):
-    """Return True if a decorated node has
-    an attr decorator applied."""
+def is_decorated_with_attrs(node, decorator_names=ATTRS_NAMES) -> bool:
+    """Return whether a decorated node has an attr decorator applied."""
     if not node.decorators:
         return False
     for decorator_attribute in node.decorators.nodes:
@@ -39,6 +49,10 @@ def is_decorated_with_attrs(node, decorator_names=ATTRS_NAMES):
             decorator_attribute = decorator_attribute.func
         if decorator_attribute.as_string() in decorator_names:
             return True
+
+        inferred = safe_infer(decorator_attribute)
+        if inferred and inferred.root().name == "attr._next_gen":
+            return True
     return False
 
 
@@ -47,7 +61,7 @@ def attr_attributes_transform(node: ClassDef) -> None:
     rewrite class attributes as instance attributes
     """
     # Astroid can't infer this attribute properly
-    # Prevents https://github.com/PyCQA/pylint/issues/1884
+    # Prevents https://github.com/pylint-dev/pylint/issues/1884
     node.locals["__attrs_attrs__"] = [Unknown(parent=node)]
 
     for cdef_body_node in node.body:
@@ -72,11 +86,12 @@ def attr_attributes_transform(node: ClassDef) -> None:
             if isinstance(target, AssignName):
                 # Could be a subscript if the code analysed is
                 # i = Optional[str] = ""
-                # See https://github.com/PyCQA/pylint/issues/4439
+                # See https://github.com/pylint-dev/pylint/issues/4439
                 node.locals[target.name] = [rhs_node]
                 node.instance_attrs[target.name] = [rhs_node]
 
 
-AstroidManager().register_transform(
-    ClassDef, attr_attributes_transform, is_decorated_with_attrs
-)
+def register(manager: AstroidManager) -> None:
+    manager.register_transform(
+        ClassDef, attr_attributes_transform, is_decorated_with_attrs
+    )
