@@ -1,20 +1,13 @@
-# Copyright (c) 2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2016-2017 Łukasz Rogalski <rogalski.91@gmail.com>
-# Copyright (c) 2017 Derek Gustafson <degustaf@gmail.com>
-# Copyright (c) 2018 Ioana Tagirta <ioana.tagirta@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 John Belmonte <john@neggie.net>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-# Copyright (c) 2022 Alexander Shadchin <alexandr.shadchin@gmail.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
+
+from __future__ import annotations
 
 from astroid.brain.helpers import register_module_extender
 from astroid.builder import extract_node, parse
 from astroid.const import PY39_PLUS
+from astroid.context import InferenceContext
 from astroid.exceptions import AttributeInferenceError
 from astroid.manager import AstroidManager
 from astroid.nodes.scoped_nodes import ClassDef
@@ -88,13 +81,10 @@ def _ordered_dict_mock():
     return base_ordered_dict_class
 
 
-register_module_extender(AstroidManager(), "collections", _collections_transform)
-
-
 def _looks_like_subscriptable(node: ClassDef) -> bool:
     """
-    Returns True if the node corresponds to a ClassDef of the Collections.abc module that
-    supports subscripting
+    Returns True if the node corresponds to a ClassDef of the Collections.abc module
+    that supports subscripting.
 
     :param node: ClassDef node
     """
@@ -116,18 +106,21 @@ def __class_getitem__(cls, item):
 """
 
 
-def easy_class_getitem_inference(node, context=None):
+def easy_class_getitem_inference(node, context: InferenceContext | None = None):
     # Here __class_getitem__ exists but is quite a mess to infer thus
     # put an easy inference tip
     func_to_add = extract_node(CLASS_GET_ITEM_TEMPLATE)
     node.locals["__class_getitem__"] = [func_to_add]
 
 
-if PY39_PLUS:
-    # Starting with Python39 some objects of the collection module are subscriptable
-    # thanks to the __class_getitem__ method but the way it is implemented in
-    # _collection_abc makes it difficult to infer. (We would have to handle AssignName inference in the
-    # getitem method of the ClassDef class) Instead we put here a mock of the __class_getitem__ method
-    AstroidManager().register_transform(
-        ClassDef, easy_class_getitem_inference, _looks_like_subscriptable
-    )
+def register(manager: AstroidManager) -> None:
+    register_module_extender(manager, "collections", _collections_transform)
+
+    if PY39_PLUS:
+        # Starting with Python39 some objects of the collection module are subscriptable
+        # thanks to the __class_getitem__ method but the way it is implemented in
+        # _collection_abc makes it difficult to infer. (We would have to handle AssignName inference in the
+        # getitem method of the ClassDef class) Instead we put here a mock of the __class_getitem__ method
+        manager.register_transform(
+            ClassDef, easy_class_getitem_inference, _looks_like_subscriptable
+        )
